=== modified file 'client/drizzle.cc'
--- client/drizzle.cc	2011-02-17 00:14:13 +0000
+++ client/drizzle.cc	2011-02-21 13:59:06 +0000
@@ -37,7 +37,7 @@
 #include <config.h>
 #include <libdrizzle/drizzle_client.h>
 
-#include <client/get_password.h>
+#include "server_detect.h"
 
 #include <boost/date_time/posix_time/posix_time.hpp>
 
@@ -307,6 +307,7 @@
 static uint32_t select_limit;
 static uint32_t max_join_size;
 static uint32_t opt_connect_timeout= 0;
+static ServerDetect::server_type server_type= ServerDetect::SERVER_UNKNOWN_FOUND;
 std::string current_db,
   delimiter_str,  
   current_host,
@@ -3128,11 +3129,13 @@
   drizzle_return_t ret;
   drizzle_column_st *field;
   std::vector<bool> num_flag;
+  std::vector<bool> boolean_flag;
   string separator;
 
   separator.reserve(256);
 
   num_flag.resize(drizzle_result_column_count(result));
+  boolean_flag.resize(drizzle_result_column_count(result));
   if (column_types_flag)
   {
     print_field_types(result);
@@ -3175,6 +3178,13 @@
       // Room for "NULL"
       length=4;
     }
+    if ((length < 5) and 
+      (server_type == ServerDetect::SERVER_DRIZZLE_FOUND) and
+      (drizzle_column_type(field) == DRIZZLE_COLUMN_TYPE_TINY))
+    {
+      // Room for "FALSE"
+      length= 5;
+    }
     drizzle_column_set_max_size(field, length);
 
     for (x=0; x< (length+2); x++)
@@ -3198,6 +3208,16 @@
                   drizzle_column_name(field));
       num_flag[off]= ((drizzle_column_type(field) <= DRIZZLE_COLUMN_TYPE_LONGLONG) ||
                       (drizzle_column_type(field) == DRIZZLE_COLUMN_TYPE_NEWDECIMAL));
+      if ((server_type == ServerDetect::SERVER_DRIZZLE_FOUND) and
+        (drizzle_column_type(field) == DRIZZLE_COLUMN_TYPE_TINY))
+      {
+        boolean_flag[off]= true;
+        num_flag[off]= false;
+      }
+      else
+      {
+        boolean_flag[off]= false;
+      }
     }
     (void) tee_fputs("\n", PAGER);
     tee_puts((char*) separator.c_str(), PAGER);
@@ -3236,6 +3256,19 @@
         buffer= "NULL";
         data_length= 4;
       }
+      else if (boolean_flag[off])
+      {
+        if (strncmp(cur[off],"1", 1) == 0)
+        {
+          buffer= "TRUE";
+          data_length= 4;
+        }
+        else
+        {
+          buffer= "FALSE";
+          data_length= 5;
+        }
+      }
       else
       {
         buffer= cur[off];
@@ -4108,6 +4141,9 @@
   }
   connected=1;
 
+  ServerDetect server_detect(&con);
+  server_type= server_detect.getServerType();
+
   build_completion_hash(opt_rehash, 1);
   return 0;
 }

=== modified file 'client/drizzledump.cc'
--- client/drizzledump.cc	2011-02-15 23:05:12 +0000
+++ client/drizzledump.cc	2011-02-21 13:59:06 +0000
@@ -241,9 +241,9 @@
     cout << "-- Host: " << current_host << "    Database: " << db_name << endl;
     cout << "-- ------------------------------------------------------" << endl;
     cout << "-- Server version\t" << db_connection->getServerVersion();
-    if (db_connection->getServerType() == DrizzleDumpConnection::SERVER_MYSQL_FOUND)
+    if (db_connection->getServerType() == ServerDetect::SERVER_MYSQL_FOUND)
       cout << " (MySQL server)";
-    else if (db_connection->getServerType() == DrizzleDumpConnection::SERVER_DRIZZLE_FOUND)
+    else if (db_connection->getServerType() == ServerDetect::SERVER_DRIZZLE_FOUND)
       cout << " (Drizzle server)";
     cout << endl << endl;
   }
@@ -351,7 +351,7 @@
     std::cerr << _("-- Retrieving database structures...") << std::endl;
 
   /* Blocking the MySQL privilege tables too because we can't import them due to bug#646187 */
-  if (db_connection->getServerType() == DrizzleDumpConnection::SERVER_MYSQL_FOUND)
+  if (db_connection->getServerType() == ServerDetect::SERVER_MYSQL_FOUND)
     query= "SELECT SCHEMA_NAME, DEFAULT_COLLATION_NAME FROM INFORMATION_SCHEMA.SCHEMATA WHERE SCHEMA_NAME NOT IN ('information_schema', 'performance_schema', 'mysql')";
   else
     query= "SELECT SCHEMA_NAME, DEFAULT_COLLATION_NAME FROM DATA_DICTIONARY.SCHEMAS WHERE SCHEMA_NAME NOT IN ('information_schema','data_dictionary')";
@@ -360,7 +360,7 @@
   while ((row= drizzle_row_next(tableres)))
   {
     std::string database_name(row[0]);
-    if (db_connection->getServerType() == DrizzleDumpConnection::SERVER_MYSQL_FOUND)
+    if (db_connection->getServerType() == ServerDetect::SERVER_MYSQL_FOUND)
       database= new DrizzleDumpDatabaseMySQL(database_name, db_connection);
     else
       database= new DrizzleDumpDatabaseDrizzle(database_name, db_connection);
@@ -383,7 +383,7 @@
   for (vector<string>::const_iterator it= db_names.begin(); it != db_names.end(); ++it)
   {
     temp= *it;
-    if (db_connection->getServerType() == DrizzleDumpConnection::SERVER_MYSQL_FOUND)
+    if (db_connection->getServerType() == ServerDetect::SERVER_MYSQL_FOUND)
       database= new DrizzleDumpDatabaseMySQL(temp, db_connection);
     else
       database= new DrizzleDumpDatabaseDrizzle(temp, db_connection);
@@ -396,7 +396,7 @@
 {
   DrizzleDumpDatabase *database;
 
-  if (db_connection->getServerType() == DrizzleDumpConnection::SERVER_MYSQL_FOUND)
+  if (db_connection->getServerType() == ServerDetect::SERVER_MYSQL_FOUND)
     database= new DrizzleDumpDatabaseMySQL(db, db_connection);
   else
     database= new DrizzleDumpDatabaseDrizzle(db, db_connection);
@@ -742,7 +742,7 @@
     maybe_exit(EX_DRIZZLEERR);
   }
 
-  if ((db_connection->getServerType() == DrizzleDumpConnection::SERVER_MYSQL_FOUND) and (not opt_data_is_mangled))
+  if ((db_connection->getServerType() == ServerDetect::SERVER_MYSQL_FOUND) and (not opt_data_is_mangled))
     db_connection->queryNoResult("SET NAMES 'utf8'");
 
   if (vm.count("destination-type"))

=== modified file 'client/drizzledump_data.cc'
--- client/drizzledump_data.cc	2010-12-08 07:35:23 +0000
+++ client/drizzledump_data.cc	2011-02-21 13:59:06 +0000
@@ -561,19 +561,10 @@
     throw std::exception();
   }
 
-  boost::match_flag_type flags = boost::match_default; 
-
-  boost::regex mysql_regex("(5\\.[0-9]+\\.[0-9]+)");
-  boost::regex drizzle_regex("(20[0-9]{2}\\.(0[1-9]|1[012])\\.[0-9]+)");
-
-  std::string version(getServerVersion());
-
-  if (regex_search(version, mysql_regex, flags))
-    serverType= SERVER_MYSQL_FOUND;
-  else if (regex_search(version, drizzle_regex, flags))
-    serverType= SERVER_DRIZZLE_FOUND;
-  else
-    serverType= SERVER_UNKNOWN_FOUND;
+  ServerDetect server_detect= ServerDetect(&connection);
+
+  serverType= server_detect.getServerType();
+  serverVersion= server_detect.getServerVersion();
 }
 
 drizzle_result_st* DrizzleDumpConnection::query(std::string &str_query)

=== modified file 'client/drizzledump_data.h'
--- client/drizzledump_data.h	2010-12-08 07:35:23 +0000
+++ client/drizzledump_data.h	2011-02-21 13:59:06 +0000
@@ -22,6 +22,7 @@
 
 #define DRIZZLE_MAX_LINE_LENGTH 1024*1024L-1025
 #include "client_priv.h"
+#include "server_detect.h"
 #include <string>
 #include <iostream>
 #include <iomanip>
@@ -214,14 +215,10 @@
     drizzle_con_st connection;
     std::string hostName;
     bool drizzleProtocol;
-    int serverType;
+    ServerDetect::server_type serverType;
+    std::string serverVersion;
 
   public:
-    enum server_type {
-      SERVER_MYSQL_FOUND,
-      SERVER_DRIZZLE_FOUND,
-      SERVER_UNKNOWN_FOUND
-    };
     DrizzleDumpConnection(std::string &host, uint16_t port,
       std::string &username, std::string &password, bool drizzle_protocol);
     ~DrizzleDumpConnection();
@@ -244,7 +241,7 @@
     bool setDB(std::string databaseName);
     bool usingDrizzleProtocol(void) const { return drizzleProtocol; }
     bool getServerType(void) const { return serverType; }
-    const char* getServerVersion(void) { return drizzle_con_server_version(&connection); }
+    std::string getServerVersion(void) const { return serverVersion; }
 };
 
 class DrizzleStringBuf : public std::streambuf

=== modified file 'client/include.am'
--- client/include.am	2010-12-28 20:54:15 +0000
+++ client/include.am	2011-02-21 13:59:06 +0000
@@ -54,6 +54,7 @@
                  client/drizzledump_drizzle.h \
                  client/drizzledump_mysql.h \
                  client/option_string.h \
+                 client/server_detect.h \
                  client/statement.h \
                  client/stats.h \
                  client/thread_context.h \

=== added file 'client/server_detect.h'
--- client/server_detect.h	1970-01-01 00:00:00 +0000
+++ client/server_detect.h	2011-02-21 13:59:06 +0000
@@ -0,0 +1,61 @@
+/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2011 Andrew Hutchings
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; version 2 of the License.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef CLIENT_SERVER_DETECT_H
+#define CLIENT_SERVER_DETECT_H
+
+#include <boost/regex.hpp>
+
+class ServerDetect
+{
+  public:
+    enum server_type {
+      SERVER_MYSQL_FOUND,
+      SERVER_DRIZZLE_FOUND,
+      SERVER_UNKNOWN_FOUND
+    };
+
+    server_type getServerType() { return type; }
+    std::string& getServerVersion() { return version; }
+
+    ServerDetect(drizzle_con_st *connection) :
+      type(SERVER_UNKNOWN_FOUND),
+      version("")
+    {
+      boost::match_flag_type flags = boost::match_default;
+
+      boost::regex mysql_regex("(5\\.[0-9]+\\.[0-9]+)");
+      boost::regex drizzle_regex("(20[0-9]{2}\\.(0[1-9]|1[012])\\.[0-9]+)");
+
+      version= drizzle_con_server_version(connection);
+
+      if (regex_search(version, mysql_regex, flags))
+        type= SERVER_MYSQL_FOUND;
+      else if (regex_search(version, drizzle_regex, flags))
+        type= SERVER_DRIZZLE_FOUND;
+      else
+        type= SERVER_UNKNOWN_FOUND;
+    }
+
+  private:
+    server_type type;
+    std::string version;
+};
+
+#endif /* CLIENT_SERVER_DETECT_H */

